@@ -38,11 +38,13 @@
 #' `terms` (the selectors or variables selected) and `value` (the
 #' lambda estimate) is returned.
 #'
+#' @template case-weights-not-supported
+#'
 #' @references Sakia, R. M. (1992). The Box-Cox transformation technique:
 #'   A review. *The Statistician*, 169-178..
 #' @examples
 #'
-#' rec <- recipe(~ ., data = as.data.frame(state.x77))
+#' rec <- recipe(~., data = as.data.frame(state.x77))
 #'
 #' bc_trans <- step_BoxCox(rec, all_numeric())
 #'
@@ -131,12 +133,13 @@ prep.step_BoxCox <- function(x, training, info = NULL, ...) {
 #' @export
 bake.step_BoxCox <- function(object, new_data, ...) {
   param <- names(object$lambdas)
+  check_new_data(param, object, new_data)
 
   for (i in seq_along(object$lambdas)) {
     new_data[, param[i]] <- bc_trans(getElement(new_data, param[i]), lambda = object$lambdas[i])
   }
 
-  as_tibble(new_data)
+  new_data
 }
 
 print.step_BoxCox <-
@@ -148,32 +151,36 @@ print.step_BoxCox <-
 
 ## computes the new data
 bc_trans <- function(x, lambda, eps = .001) {
-
-  if (any(x <= 0))
+  if (any(x <= 0)) {
     rlang::warn(paste0(
       "Applying Box-Cox transformation to non-positive data in column `",
       names(lambda), "`"
-      ))
+    ))
+  }
 
-  if (is.na(lambda))
+  if (is.na(lambda)) {
     return(x)
-  if (abs(lambda) < eps)
+  }
+  if (abs(lambda) < eps) {
     log(x)
-  else
-    (x ^ lambda - 1) / lambda
+  } else {
+    (x^lambda - 1) / lambda
+  }
 }
 
 ## helper for the log-likelihood calc
 
+# TODO case weights: Is there a weighted version of this likelihood?
 ll_bc <- function(lambda, y, gm, eps = .001) {
   n <- length(y)
-  gm0 <- gm ^ (lambda - 1)
-  z <- if (abs(lambda) <= eps)
+  gm0 <- gm^(lambda - 1)
+  z <- if (abs(lambda) <= eps) {
     log(y) / gm0
-  else
-    (y ^ lambda - 1) / (lambda * gm0)
+  } else {
+    (y^lambda - 1) / (lambda * gm0)
+  }
   var_z <- var(z) * (n - 1) / n
-  - .5 * n * log(var_z)
+  -.5 * n * log(var_z)
 }
 
 
@@ -207,8 +214,9 @@ estimate_bc <- function(dat,
     tol = .0001
   )
   lam <- res$maximum
-  if (abs(limits[1] - lam) <= eps | abs(limits[2] - lam) <= eps)
+  if (abs(limits[1] - lam) <= eps | abs(limits[2] - lam) <= eps) {
     lam <- NA
+  }
   lam
 }
 
@@ -217,12 +225,16 @@ estimate_bc <- function(dat,
 #' @export
 tidy.step_BoxCox <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$lambdas),
-                  value = unname(x$lambdas))
+    res <- tibble(
+      terms = names(x$lambdas),
+      value = unname(x$lambdas)
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_dbl)
+    res <- tibble(
+      terms = term_names,
+      value = na_dbl
+    )
   }
   res$id <- x$id
   res
