@@ -31,15 +31,18 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #'  `terms` (the columns that will be affected) is returned.
 #'
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @template case-weights-not-supported
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
+#'
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'   data = biomass_tr
+#' )
 #'
 #' with_splines <- rec %>%
 #'   step_bs(carbon, hydrogen)
@@ -58,7 +61,6 @@ step_bs <-
            options = list(),
            skip = FALSE,
            id = rand_id("bs")) {
-
     add_step(
       recipe,
       step_bs_new(
@@ -156,6 +158,8 @@ prep.step_bs <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_bs <- function(object, new_data, ...) {
+  check_new_data(names(object$objects), object, new_data)
+
   ## pre-allocate a matrix for the basis functions.
   new_cols <- vapply(object$objects, ncol, c(int = 1L))
   bs_values <-
@@ -174,8 +178,6 @@ bake.step_bs <- function(object, new_data, ...) {
     new_data[, orig_var] <- NULL
   }
   new_data <- bind_cols(new_data, as_tibble(bs_values))
-  if (!is_tibble(new_data))
-    new_data <- as_tibble(new_data)
   new_data
 }
 
