@@ -38,15 +38,18 @@
 #'  `terms` (the selectors or variables selected) and `value` (the means)
 #'  is returned.
 #'
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @template case-weights-unsupervised
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
+#'
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'   data = biomass_tr
+#' )
 #'
 #' center_trans <- rec %>%
 #'   step_center(carbon, contains("gen"), -hydrogen)
@@ -78,14 +81,15 @@ step_center <-
         means = means,
         na_rm = na_rm,
         skip = skip,
-        id = id
+        id = id,
+        case_weights = NULL
       )
     )
   }
 
 ## Initializes a new object
 step_center_new <-
-  function(terms, role, trained, means, na_rm, skip, id) {
+  function(terms, role, trained, means, na_rm, skip, id, case_weights) {
     step(
       subclass = "center",
       terms = terms,
@@ -94,7 +98,8 @@ step_center_new <-
       means = means,
       na_rm = na_rm,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
@@ -103,8 +108,14 @@ prep.step_center <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
-  means <-
-    vapply(training[, col_names], mean, c(mean = 0), na.rm = x$na_rm)
+  wts <- get_case_weights(info, training)
+  were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
+  if (isFALSE(were_weights_used)) {
+    wts <- NULL
+  }
+
+  means <- averages(training[, col_names], wts, na_rm = x$na_rm)
+
   step_center_new(
     terms = x$terms,
     role = x$role,
@@ -112,23 +123,27 @@ prep.step_center <- function(x, training, info = NULL, ...) {
     means = means,
     na_rm = x$na_rm,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
 #' @export
 bake.step_center <- function(object, new_data, ...) {
-  res <-
-    sweep(as.matrix(new_data[, names(object$means)]), 2, object$means, "-")
-  res <- tibble::as_tibble(res)
-  new_data[, names(object$means)] <- res
-  as_tibble(new_data)
+  check_new_data(names(object$means), object, new_data)
+
+  for (column in names(object$means)) {
+    mean <- object$means[column]
+    new_data[[column]] <- new_data[[column]] - mean
+  }
+  new_data
 }
 
 print.step_center <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Centering for "
-    print_step(names(x$means), x$terms, x$trained, title, width)
+    print_step(names(x$means), x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
@@ -137,12 +152,16 @@ print.step_center <-
 #' @export
 tidy.step_center <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$means),
-                  value = unname(x$means))
+    res <- tibble(
+      terms = names(x$means),
+      value = unname(x$means)
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_dbl)
+    res <- tibble(
+      terms = term_names,
+      value = na_dbl
+    )
   }
   res$id <- x$id
   res
