@@ -27,9 +27,10 @@
 #' `terms` (the selectors or variables selected) and `model` (the mode
 #' value) is returned.
 #'
-#' @examples
-#' library(modeldata)
-#' data("credit_data")
+#' @template case-weights-unsupervised
+#'
+#' @examplesIf rlang::is_installed("modeldata")
+#' data("credit_data", package = "modeldata")
 #'
 #' ## missing data per column
 #' vapply(credit_data, function(x) mean(is.na(x)), c(num = 0))
@@ -37,7 +38,7 @@
 #' set.seed(342)
 #' in_training <- sample(1:nrow(credit_data), 2000)
 #'
-#' credit_tr <- credit_data[ in_training, ]
+#' credit_tr <- credit_data[in_training, ]
 #' credit_te <- credit_data[-in_training, ]
 #' missing_examples <- c(14, 394, 565)
 #'
@@ -54,7 +55,6 @@
 #'
 #' tidy(impute_rec, number = 1)
 #' tidy(imp_models, number = 1)
-
 step_impute_mode <-
   function(recipe,
            ...,
@@ -73,7 +73,8 @@ step_impute_mode <-
         modes = modes,
         ptype = ptype,
         skip = skip,
-        id = id
+        id = id,
+        case_weights = NULL
       )
     )
   }
@@ -89,7 +90,7 @@ step_modeimpute <-
            ptype = NULL,
            skip = FALSE,
            id = rand_id("impute_mode")) {
-    lifecycle::deprecate_warn(
+    lifecycle::deprecate_stop(
       when = "0.1.16",
       what = "recipes::step_modeimpute()",
       with = "recipes::step_impute_mode()"
@@ -107,7 +108,7 @@ step_modeimpute <-
   }
 
 step_impute_mode_new <-
-  function(terms, role, trained, modes, ptype, skip, id) {
+  function(terms, role, trained, modes, ptype, skip, id, case_weights) {
     step(
       subclass = "impute_mode",
       terms = terms,
@@ -116,14 +117,22 @@ step_impute_mode_new <-
       modes = modes,
       ptype = ptype,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
 #' @export
 prep.step_impute_mode <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  modes <- vapply(training[, col_names], mode_est, c(mode = ""))
+
+  wts <- get_case_weights(info, training)
+  were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
+  if (isFALSE(were_weights_used)) {
+    wts <- NULL
+  }
+
+  modes <- vapply(training[, col_names], mode_est, c(mode = ""), wts = wts)
   ptype <- vec_slice(training[, col_names], 0)
   step_impute_mode_new(
     terms = x$terms,
@@ -132,7 +141,8 @@ prep.step_impute_mode <- function(x, training, info = NULL, ...) {
     modes = modes,
     ptype = ptype,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
@@ -142,10 +152,11 @@ prep.step_modeimpute <- prep.step_impute_mode
 
 #' @export
 bake.step_impute_mode <- function(object, new_data, ...) {
+  check_new_data(names(object$modes), object, new_data)
 
   for (i in names(object$modes)) {
     if (any(is.na(new_data[, i]))) {
-      if(is.null(object$ptype)) {
+      if (is.null(object$ptype)) {
         rlang::warn(
           paste0(
             "'ptype' was added to `step_impute_mode()` after this recipe was created.\n",
@@ -159,7 +170,7 @@ bake.step_impute_mode <- function(object, new_data, ...) {
       new_data[is.na(new_data[[i]]), i] <- mode_val
     }
   }
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
@@ -170,7 +181,8 @@ bake.step_modeimpute <- bake.step_impute_mode
 print.step_impute_mode <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Mode imputation for "
-    print_step(names(x$modes), x$terms, x$trained, title, width)
+    print_step(names(x$modes), x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
@@ -178,10 +190,10 @@ print.step_impute_mode <-
 #' @keywords internal
 print.step_modeimpute <- print.step_impute_mode
 
-mode_est <- function(x) {
+mode_est <- function(x, wts = NULL) {
   if (!is.character(x) & !is.factor(x))
     rlang::abort("The data should be character or factor to compute the mode.")
-  tab <- table(x)
+  tab <- weighted_table(x, wts = wts)
   modes <- names(tab)[tab == max(tab)]
   sample(modes, size = 1)
 }
@@ -190,8 +202,10 @@ mode_est <- function(x) {
 #' @export
 tidy.step_impute_mode <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$modes),
-                  model = unname(x$modes))
+    res <- tibble(
+      terms = names(x$modes),
+      model = unname(x$modes)
+    )
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, model = na_chr)
