@@ -17,15 +17,18 @@
 #' @export
 #' @template kpca-info
 #'
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @template case-weights-not-supported
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' @examplesIf rlang::is_installed(c("modeldata", "ggplot2","kernlab"))
+#' data(biomass, package = "modeldata")
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
+#'
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'   data = biomass_tr
+#' )
 #'
 #' kpca_trans <- rec %>%
 #'   step_YeoJohnson(all_numeric_predictors()) %>%
@@ -38,13 +41,12 @@
 #'   kpca_te <- bake(kpca_estimates, biomass_te)
 #'
 #'   ggplot(kpca_te, aes(x = kPC1, y = kPC2)) +
-#'    geom_point() +
-#'    coord_equal()
+#'     geom_point() +
+#'     coord_equal()
 #'
 #'   tidy(kpca_trans, number = 3)
 #'   tidy(kpca_estimates, number = 3)
 #' }
-#'
 step_kpca_poly <-
   function(recipe,
            ...,
@@ -60,7 +62,6 @@ step_kpca_poly <-
            keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("kpca_poly")) {
-
     recipes_pkg_check(required_pkgs.step_kpca_poly())
 
     add_step(
@@ -152,7 +153,9 @@ prep.step_kpca_poly <- function(x, training, info = NULL, ...) {
 #' @export
 bake.step_kpca_poly <- function(object, new_data, ...) {
   uses_dim_red(object)
+
   if (object$num_comp > 0 && length(object$columns) > 0) {
+    check_new_data(object$columns, object, new_data)
     cl <-
       rlang::call2(
         "predict",
@@ -171,7 +174,7 @@ bake.step_kpca_poly <- function(object, new_data, ...) {
       new_data <- new_data[, !(colnames(new_data) %in% object$columns), drop = FALSE]
     }
   }
-  as_tibble(new_data)
+  new_data
 }
 
 print.step_kpca_poly <- function(x, width = max(20, options()$width - 40), ...) {
