@@ -25,21 +25,27 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #'  `terms` (the columns that will be removed) is returned.
 #'
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @template case-weights-not-supported
 #'
-#' biomass$new_1 <- with(biomass,
-#'                       .1*carbon - .2*hydrogen + .6*sulfur)
-#' biomass$new_2 <- with(biomass,
-#'                       .5*carbon - .2*oxygen + .6*nitrogen)
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' biomass$new_1 <- with(
+#'   biomass,
+#'   .1 * carbon - .2 * hydrogen + .6 * sulfur
+#' )
+#' biomass$new_2 <- with(
+#'   biomass,
+#'   .5 * carbon - .2 * oxygen + .6 * nitrogen
+#' )
+#'
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
 #'
 #' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen +
-#'                 sulfur + new_1 + new_2,
-#'               data = biomass_tr)
+#'   sulfur + new_1 + new_2,
+#' data = biomass_tr
+#' )
 #'
 #' lincomb_filter <- rec %>%
 #'   step_lincomb(all_numeric_predictors())
@@ -92,8 +98,10 @@ prep.step_lincomb <- function(x, training, info = NULL, ...) {
 
   check_type(training[, col_names])
 
-  filter <- iter_lc_rm(x = training[, col_names],
-                       max_steps = x$max_steps)
+  filter <- iter_lc_rm(
+    x = training[, col_names],
+    max_steps = x$max_steps
+  )
 
   step_lincomb_new(
     terms = x$terms,
@@ -108,13 +116,14 @@ prep.step_lincomb <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_lincomb <- function(object, new_data, ...) {
-  if (length(object$removals) > 0)
+  if (length(object$removals) > 0) {
     new_data <- new_data[, !(colnames(new_data) %in% object$removals)]
-  as_tibble(new_data)
+  }
+  new_data
 }
 
 print.step_lincomb <-
-  function(x,  width = max(20, options()$width - 36), ...) {
+  function(x, width = max(20, options()$width - 36), ...) {
     if (x$trained) {
       title <- "Linear combination filter removed "
     } else {
@@ -125,35 +134,41 @@ print.step_lincomb <-
   }
 
 
-recommend_rm <- function(x, eps  = 1e-6, ...) {
-  if (!is.matrix(x))
+recommend_rm <- function(x, eps = 1e-6, ...) {
+  if (!is.matrix(x)) {
     x <- as.matrix(x)
-  if (is.null(colnames(x)))
+  }
+  if (is.null(colnames(x))) {
     rlang::abort("`x` should have column names")
+  }
 
   qr_decomp <- qr(x)
-  qr_decomp_R <- qr.R(qr_decomp)           # extract R matrix
-  num_cols <- ncol(qr_decomp_R)            # number of columns in R
-  rank <- qr_decomp$rank                   # number of independent columns
-  pivot <- qr_decomp$pivot                 # get the pivot vector
+  qr_decomp_R <- qr.R(qr_decomp) # extract R matrix
+  num_cols <- ncol(qr_decomp_R) # number of columns in R
+  rank <- qr_decomp$rank # number of independent columns
+  pivot <- qr_decomp$pivot # get the pivot vector
 
   if (is.null(num_cols) || rank == num_cols) {
-    rm_list <- character(0)                 # there are no linear combinations
+    rm_list <- character(0) # there are no linear combinations
   } else {
     p1 <- 1:rank
-    X <- qr_decomp_R[p1, p1]                # extract the independent columns
+    X <- qr_decomp_R[p1, p1] # extract the independent columns
     Y <- qr_decomp_R[p1, -p1, drop = FALSE] # extract the dependent columns
-    b <- qr(X)                              # factor the independent columns
-    b <- qr.coef(b, Y)                      # get regression coefficients of
-                                            # the dependent columns
-    b[abs(b) < eps] <- 0                    # zap small values
+    b <- qr(X) # factor the independent columns
+    b <- qr.coef(b, Y) # get regression coefficients of
+    # the dependent columns
+    b[abs(b) < eps] <- 0 # zap small values
 
     # generate a list with one element for each dependent column
-    combos <- lapply(1:ncol(Y),
-                     function(i)
-                       c(pivot[rank + i], pivot[which(b[, i] != 0)]))
-    rm_list <- unlist(lapply(combos, function(x)
-      x[1]))
+    combos <- lapply(
+      1:ncol(Y),
+      function(i) {
+        c(pivot[rank + i], pivot[which(b[, i] != 0)])
+      }
+    )
+    rm_list <- unlist(lapply(combos, function(x) {
+      x[1]
+    }))
     rm_list <- colnames(x)[rm_list]
   }
   rm_list
@@ -167,34 +182,42 @@ iter_lc_rm <- function(x,
     return(character())
   }
 
-  if (is.null(colnames(x)))
+  if (is.null(colnames(x))) {
     rlang::abort("`x` should have column names")
+  }
 
   orig_names <- colnames(x)
-  if (!is.matrix(x))
+  if (!is.matrix(x)) {
     x <- as.matrix(x)
+  }
 
   # converting to matrix may alter column names
-  name_df <- data.frame(orig = orig_names,
-                        current = colnames(x),
-                        stringsAsFactors = FALSE)
+  name_df <- data.frame(
+    orig = orig_names,
+    current = colnames(x),
+    stringsAsFactors = FALSE
+  )
 
   for (i in 1:max_steps) {
-    if (verbose)
+    if (verbose) {
       cat(i)
-    if (i == max_steps)
-      break ()
+    }
+    if (i == max_steps) {
+      break()
+    }
     lcs <- recommend_rm(x)
-    if (length(lcs) == 0)
-      break ()
-    else {
-      if (verbose)
+    if (length(lcs) == 0) {
+      break()
+    } else {
+      if (verbose) {
         cat(" removing", length(lcs), "\n")
+      }
       x <- x[, !(colnames(x) %in% lcs)]
     }
   }
-  if (verbose)
+  if (verbose) {
     cat("\n")
+  }
   name_df <- name_df[!(name_df$current %in% colnames(x)), ]
   name_df$orig
 }
