@@ -57,24 +57,26 @@
 #' above. When you `tidy()` this step, a tibble with columns `terms` (the
 #' selectors or variables selected), `components`, and `values` is returned.
 #'
+#' @template case-weights-not-supported
+#'
 #' @references
 #' \url{https://en.wikipedia.org/wiki/Partial_least_squares_regression}
 #'
 #' Rohart F, Gautier B, Singh A, Lê Cao K-A (2017) _mixOmics: An R package for
 #' 'omics feature selection and multiple data integration_. PLoS Comput Biol
 #' 13(11): e1005752. \doi{10.1371/journal.pcbi.1005752}
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
 #' # requires the Bioconductor mixOmics package
 #' data(biomass, package = "modeldata")
 #'
 #' biom_tr <-
 #'   biomass %>%
 #'   dplyr::filter(dataset == "Training") %>%
-#'   dplyr::select(-dataset,-sample)
+#'   dplyr::select(-dataset, -sample)
 #' biom_te <-
 #'   biomass %>%
-#'   dplyr::filter(dataset == "Testing")  %>%
-#'   dplyr::select(-dataset,-sample,-HHV)
+#'   dplyr::filter(dataset == "Testing") %>%
+#'   dplyr::select(-dataset, -sample, -HHV)
 #'
 #' dense_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
@@ -82,7 +84,7 @@
 #'
 #' sparse_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
-#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4/5)
+#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4 / 5)
 #'
 #' ## -----------------------------------------------------------------------------
 #' ## PLS discriminant analysis
@@ -95,8 +97,8 @@
 #'   dplyr::select(-case)
 #' cell_te <-
 #'   cells %>%
-#'   dplyr::filter(case == "Test")  %>%
-#'   dplyr::select(-case,-class)
+#'   dplyr::filter(case == "Test") %>%
+#'   dplyr::select(-case, -class)
 #'
 #' dense_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
@@ -104,14 +106,13 @@
 #'
 #' sparse_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
-#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
-#'
+#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1 / 4)
 step_pls <-
   function(recipe,
            ...,
            role = "predictor",
            trained = FALSE,
-           num_comp  = 2,
+           num_comp = 2,
            predictor_prop = 1,
            outcome = NULL,
            options = list(scale = TRUE),
@@ -127,7 +128,7 @@ step_pls <-
     }
 
     if (lifecycle::is_present(preserve)) {
-      lifecycle::deprecate_warn(
+      lifecycle::deprecate_stop(
         "0.1.16",
         "step_pls(preserve = )",
         "step_pls(keep_original_cols = )"
@@ -203,31 +204,43 @@ pls_fit <- function(x, y, ncomp = NULL, keepX = NULL, ...) {
   }
   if (is.factor(y)) {
     if (all(keepX == p)) {
-      cl  <- rlang::call2("plsda", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, !!!dots)
+      cl <- rlang::call2("plsda", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, !!!dots)
     } else {
-      cl  <- rlang::call2("splsda", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, keepX = keepX, !!!dots)
+      cl <- rlang::call2("splsda", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, keepX = keepX, !!!dots)
     }
   } else {
     if (all(keepX == p)) {
-      cl  <- rlang::call2("pls", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, !!!dots)
+      cl <- rlang::call2("pls", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, !!!dots)
     } else {
-      cl  <- rlang::call2("spls", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, keepX = keepX, !!!dots)
+      cl <- rlang::call2("spls", .ns = "mixOmics", X = quote(x), Y = quote(y), ncomp = ncomp, keepX = keepX, !!!dots)
     }
   }
   res <- rlang::eval_tidy(cl)
   res
 }
 
-make_pls_call <- function(ncomp, keepX, args = NULL) {
-  cl <-
-    rlang::call2(
-      "pls_fit",
-      x = rlang::expr(as.matrix(training[, x_names])),
-      y = rlang::expr(training[[y_names]]),
-      ncomp = ncomp,
-      keepX = keepX,
-      !!!args
-    )
+make_pls_call <- function(ncomp, keepX, y_names, args = NULL) {
+  if (length(y_names) == 1) {
+    cl <-
+      rlang::call2(
+        "pls_fit",
+        x = rlang::expr(as.matrix(training[, x_names])),
+        y = rlang::expr(training[[y_names]]),
+        ncomp = ncomp,
+        keepX = keepX,
+        !!!args
+      )
+  } else {
+    cl <-
+      rlang::call2(
+        "pls_fit",
+        x = rlang::expr(as.matrix(training[, x_names])),
+        y = rlang::expr(as.matrix(training[, y_names])),
+        ncomp = ncomp,
+        keepX = keepX,
+        !!!args
+      )
+  }
   cl
 }
 
@@ -239,10 +252,10 @@ butcher_pls <- function(x) {
   }
   .mu <- attr(x$X, "scaled:center")
   .sd <- attr(x$X, "scaled:scale")
-  W <- x$loadings$X  # W matrix, P = X'rot
+  W <- x$loadings$X # W matrix, P = X'rot
   variates <- x$variates[["X"]]
   P <- crossprod(x$X, variates)
-  coefs <- W %*% solve(t(P) %*%  W)
+  coefs <- W %*% solve(t(P) %*% W)
 
   col_norms <- apply(variates, 2, get_norms)
 
@@ -268,9 +281,9 @@ old_pls_project <- function(object, x) {
   n <- nrow(x)
   input_data <- as.matrix(x[, pls_vars])
   if (!all(is.na(object$scale))) {
-    input_data <- sweep(input_data, 2, object$scale,  "/")
+    input_data <- sweep(input_data, 2, object$scale, "/")
   }
-  input_data <- sweep(input_data, 2, object$Xmeans,  "-")
+  input_data <- sweep(input_data, 2, object$Xmeans, "-")
   comps <- input_data %*% object$projection
   colnames(comps) <- paste0("pls", 1:ncol(comps))
   tibble::as_tibble(comps)
@@ -306,18 +319,20 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
   y_names <- recipes_eval_select(x$outcome, training, info)
 
   check_type(training[, x_names])
-  if (length(y_names) > 1 ) {
-    rlang::abort("`step_pls()` only supports univariate models.")
+  if (length(y_names) > 1 && any(!map_lgl(training[y_names], is.numeric))) {
+    rlang::abort(
+      "`step_pls()` only supports multivariate models for numeric outcomes."
+    )
   }
 
   if (x$num_comp > 0 && length(x_names) > 0) {
-    ncomp <- min(x$num_comp,  length(x_names))
+    ncomp <- min(x$num_comp, length(x_names))
     # Convert proportion to number of terms
     x$predictor_prop <- max(x$predictor_prop, 0.00001)
     x$predictor_prop <- min(x$predictor_prop, 1)
     nterm <- prop2int(x$predictor_prop, length(x_names))
 
-    cl <- make_pls_call(ncomp, nterm, x$options)
+    cl <- make_pls_call(ncomp, nterm, y_names, x$options)
     res <- try(rlang::eval_tidy(cl), silent = TRUE)
     if (inherits(res, "try-error")) {
       rlang::warn(paste0("`step_pls()` failed: ", as.character(res)))
@@ -325,7 +340,6 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     } else {
       res <- butcher_pls(res)
     }
-
   } else {
     res <- NULL
   }
@@ -350,8 +364,9 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_pls <- function(object, new_data, ...) {
-  if (object$num_comp > 0 && length(get_columns_pls(object)) > 0 && pls_worked(object$res)) {
+  check_new_data(get_columns_pls(object), object, new_data)
 
+  if (object$num_comp > 0 && length(get_columns_pls(object)) > 0 && pls_worked(object$res)) {
     if (use_old_pls(object$res)) {
       comps <- old_pls_project(object$res, new_data)
     } else {
@@ -375,10 +390,6 @@ bake.step_pls <- function(object, new_data, ...) {
       keep_vars <- !(colnames(new_data) %in% pls_vars)
       new_data <- new_data[, keep_vars, drop = FALSE]
     }
-
-    if (!is_tibble(new_data)) {
-      new_data <- as_tibble(new_data)
-    }
   }
   new_data
 }
@@ -403,7 +414,7 @@ tidy.step_pls <- function(x, ...) {
       res <- res[, c("terms", "value", "component")]
       res$component <- gsub("comp", "PLS", res$component)
     } else {
-      res <- tibble(terms = unname(get_columns_pls(x)), value = na_dbl, component  = na_chr)
+      res <- tibble(terms = unname(get_columns_pls(x)), value = na_dbl, component = na_chr)
     }
   } else {
     term_names <- sel2char(x$terms)
